bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.plates
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: WrapToGaussianWishart.plates